pub fn parse_nth(input: &mut Parser<'_>) -> Result<(i32, i32), BasicParseError>Expand description
Parse the An+B notation, as found in the :nth-child() selector.
The input is typically the arguments of a function,
in which case the caller needs to check if the arguments’ parser is exhausted.
Return Ok((A, B)), or an Err(..) for a syntax error.